@@ -1,8 +1,8 @@
 import os
 import sys
 
-from helpycli import appsettings
+from cythonbuilder import appsettings
 
 ROOT_DIR = os.path.realpath(os.path.join(os.path.dirname(__file__), '..'))
-PACKAGE_ROOT = sys.modules[appsettings.helpy_package_name].__path__[0]
+PACKAGE_ROOT = sys.modules[appsettings.package_name].__path__[0]
 
